# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui_linearview_options.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_LinearViewOptionsDialog(object):
    def setupUi(self, LinearViewOptionsDialog):
        LinearViewOptionsDialog.setObjectName("LinearViewOptionsDialog")
        LinearViewOptionsDialog.resize(614, 180)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(LinearViewOptionsDialog)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.groupBox_5 = QtWidgets.QGroupBox(LinearViewOptionsDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_5.sizePolicy().hasHeightForWidth())
        self.groupBox_5.setSizePolicy(sizePolicy)
        self.groupBox_5.setObjectName("groupBox_5")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.groupBox_5)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.lv_cbtitlesize = QtWidgets.QComboBox(self.groupBox_5)
        self.lv_cbtitlesize.setObjectName("lv_cbtitlesize")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.lv_cbtitlesize.addItem("")
        self.gridLayout_4.addWidget(self.lv_cbtitlesize, 3, 1, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.groupBox_5)
        self.label_2.setObjectName("label_2")
        self.gridLayout_4.addWidget(self.label_2, 3, 2, 1, 1)
        self.lv_cbaxessize = QtWidgets.QComboBox(self.groupBox_5)
        self.lv_cbaxessize.setObjectName("lv_cbaxessize")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.lv_cbaxessize.addItem("")
        self.gridLayout_4.addWidget(self.lv_cbaxessize, 3, 3, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox_5)
        self.label.setObjectName("label")
        self.gridLayout_4.addWidget(self.label, 3, 0, 1, 1)
        self.verticalLayout_4.addWidget(self.groupBox_5)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem)
        self.buttonBox = QtWidgets.QDialogButtonBox(LinearViewOptionsDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout_4.addWidget(self.buttonBox)

        self.retranslateUi(LinearViewOptionsDialog)
        self.buttonBox.accepted.connect(LinearViewOptionsDialog.accept)
        self.buttonBox.rejected.connect(LinearViewOptionsDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(LinearViewOptionsDialog)

    def retranslateUi(self, LinearViewOptionsDialog):
        _translate = QtCore.QCoreApplication.translate
        LinearViewOptionsDialog.setWindowTitle(_translate("LinearViewOptionsDialog", "Linear View Options"))
        self.groupBox_5.setTitle(_translate("LinearViewOptionsDialog", "Plot Options"))
        self.lv_cbtitlesize.setItemText(0, _translate("LinearViewOptionsDialog", "default"))
        self.lv_cbtitlesize.setItemText(1, _translate("LinearViewOptionsDialog", "4"))
        self.lv_cbtitlesize.setItemText(2, _translate("LinearViewOptionsDialog", "6"))
        self.lv_cbtitlesize.setItemText(3, _translate("LinearViewOptionsDialog", "8"))
        self.lv_cbtitlesize.setItemText(4, _translate("LinearViewOptionsDialog", "10"))
        self.lv_cbtitlesize.setItemText(5, _translate("LinearViewOptionsDialog", "12"))
        self.lv_cbtitlesize.setItemText(6, _translate("LinearViewOptionsDialog", "14"))
        self.lv_cbtitlesize.setItemText(7, _translate("LinearViewOptionsDialog", "16"))
        self.lv_cbtitlesize.setItemText(8, _translate("LinearViewOptionsDialog", "18"))
        self.lv_cbtitlesize.setItemText(9, _translate("LinearViewOptionsDialog", "20"))
        self.lv_cbtitlesize.setItemText(10, _translate("LinearViewOptionsDialog", "22"))
        self.lv_cbtitlesize.setItemText(11, _translate("LinearViewOptionsDialog", "24"))
        self.lv_cbtitlesize.setItemText(12, _translate("LinearViewOptionsDialog", "26"))
        self.lv_cbtitlesize.setItemText(13, _translate("LinearViewOptionsDialog", "28"))
        self.lv_cbtitlesize.setItemText(14, _translate("LinearViewOptionsDialog", "30"))
        self.lv_cbtitlesize.setItemText(15, _translate("LinearViewOptionsDialog", "32"))
        self.label_2.setText(_translate("LinearViewOptionsDialog", " Axes Label Size  "))
        self.lv_cbaxessize.setItemText(0, _translate("LinearViewOptionsDialog", "default"))
        self.lv_cbaxessize.setItemText(1, _translate("LinearViewOptionsDialog", "4"))
        self.lv_cbaxessize.setItemText(2, _translate("LinearViewOptionsDialog", "6"))
        self.lv_cbaxessize.setItemText(3, _translate("LinearViewOptionsDialog", "8"))
        self.lv_cbaxessize.setItemText(4, _translate("LinearViewOptionsDialog", "10"))
        self.lv_cbaxessize.setItemText(5, _translate("LinearViewOptionsDialog", "12"))
        self.lv_cbaxessize.setItemText(6, _translate("LinearViewOptionsDialog", "14"))
        self.lv_cbaxessize.setItemText(7, _translate("LinearViewOptionsDialog", "16"))
        self.lv_cbaxessize.setItemText(8, _translate("LinearViewOptionsDialog", "18"))
        self.lv_cbaxessize.setItemText(9, _translate("LinearViewOptionsDialog", "20"))
        self.lv_cbaxessize.setItemText(10, _translate("LinearViewOptionsDialog", "22"))
        self.lv_cbaxessize.setItemText(11, _translate("LinearViewOptionsDialog", "24"))
        self.lv_cbaxessize.setItemText(12, _translate("LinearViewOptionsDialog", "26"))
        self.lv_cbaxessize.setItemText(13, _translate("LinearViewOptionsDialog", "28"))
        self.lv_cbaxessize.setItemText(14, _translate("LinearViewOptionsDialog", "30"))
        self.lv_cbaxessize.setItemText(15, _translate("LinearViewOptionsDialog", "32"))
        self.label.setText(_translate("LinearViewOptionsDialog", " Plot Title Size"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    LinearViewOptionsDialog = QtWidgets.QDialog()
    ui = Ui_LinearViewOptionsDialog()
    ui.setupUi(LinearViewOptionsDialog)
    LinearViewOptionsDialog.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mslib/msui/ui/ui_shortcuts.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_ShortcutsDialog(object):
    def setupUi(self, ShortcutsDialog):
        ShortcutsDialog.setObjectName("ShortcutsDialog")
        ShortcutsDialog.resize(478, 371)
        self.verticalLayout = QtWidgets.QVBoxLayout(ShortcutsDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(ShortcutsDialog)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.leShortcutFilter = QtWidgets.QLineEdit(ShortcutsDialog)
        self.leShortcutFilter.setObjectName("leShortcutFilter")
        self.horizontalLayout.addWidget(self.leShortcutFilter)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.cbNoShortcut = QtWidgets.QCheckBox(ShortcutsDialog)
        self.cbNoShortcut.setObjectName("cbNoShortcut")
        self.horizontalLayout_3.addWidget(self.cbNoShortcut)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.line = QtWidgets.QFrame(ShortcutsDialog)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_3.addWidget(self.line)
        self.label_2 = QtWidgets.QLabel(ShortcutsDialog)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_3.addWidget(self.label_2)
        self.cbDisplayType = QtWidgets.QComboBox(ShortcutsDialog)
        self.cbDisplayType.setObjectName("cbDisplayType")
        self.cbDisplayType.addItem("")
        self.cbDisplayType.addItem("")
        self.cbDisplayType.addItem("")
        self.horizontalLayout_3.addWidget(self.cbDisplayType)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.treeWidget = QtWidgets.QTreeWidget(ShortcutsDialog)
        self.treeWidget.setObjectName("treeWidget")
        self.treeWidget.headerItem().setText(0, "1")
        self.treeWidget.header().setVisible(False)
        self.treeWidget.header().setCascadingSectionResizes(True)
        self.verticalLayout.addWidget(self.treeWidget)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.cbAdvanced = QtWidgets.QCheckBox(ShortcutsDialog)
        self.cbAdvanced.setObjectName("cbAdvanced")
        self.horizontalLayout_2.addWidget(self.cbAdvanced)
        self.buttonBox = QtWidgets.QDialogButtonBox(ShortcutsDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Close)
        self.buttonBox.setObjectName("buttonBox")
        self.horizontalLayout_2.addWidget(self.buttonBox)
        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.retranslateUi(ShortcutsDialog)
        self.buttonBox.accepted.connect(ShortcutsDialog.accept)
        self.buttonBox.rejected.connect(ShortcutsDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(ShortcutsDialog)

    def retranslateUi(self, ShortcutsDialog):
        _translate = QtCore.QCoreApplication.translate
        ShortcutsDialog.setWindowTitle(_translate("ShortcutsDialog", "Shortcuts"))
        self.label.setText(_translate("ShortcutsDialog", "Filter:"))
        self.cbNoShortcut.setText(_translate("ShortcutsDialog", "Show items without shortcut"))
        self.label_2.setText(_translate("ShortcutsDialog", "Display type:"))
        self.cbDisplayType.setItemText(0, _translate("ShortcutsDialog", "Tooltip"))
        self.cbDisplayType.setItemText(1, _translate("ShortcutsDialog", "Text"))
        self.cbDisplayType.setItemText(2, _translate("ShortcutsDialog", "ObjectName"))
        self.cbAdvanced.setText(_translate("ShortcutsDialog", "Advanced Settings"))



# -*- coding: utf-8 -*-
"""

    mslib.msui.performance_settings
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    This module defines the performance settings dialog

    This file is part of mss.

    :copyright: Copyright 2017 Joern Ungermann
    :copyright: Copyright 2017-2021 by the mss team, see AUTHORS.
    :license: APACHE-2.0, see LICENSE for details.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

import json

from PyQt5 import QtCore, QtWidgets

from mslib.utils import FatalUserError
from mslib.msui import aircrafts, constants
from mslib.msui.mss_qt import get_open_filename
from mslib.msui.mss_qt import ui_performance_dockwidget as ui_dw


DEFAULT_PERFORMANCE = {
    "aircraft": aircrafts.SimpleAircraft(aircrafts.AIRCRAFT_DUMMY),
    "visible": False,
    "takeoff_weight": 0,
    "takeoff_time": QtCore.QDateTime.currentDateTimeUtc(),
    "empty_weight": 0,
    "ceiling_alt": [410],
}


class MSS_PerformanceSettingsWidget(QtWidgets.QWidget, ui_dw.Ui_PerformanceDockWidget):
    """
    This class implements setting the performance settings as a dockable widget.
    """

    def __init__(self, parent=None, view=None, settings_dict=None):
        """
        Arguments:
        parent -- Qt widget that is parent to this widget.
        view -- reference to mpl canvas class
        settings_dict -- dictionary containing topview options
        """
        super(MSS_PerformanceSettingsWidget, self).__init__(parent)
        self.setupUi(self)
        self.view = view
        self.parent = parent

        if not settings_dict:
            settings_dict = DEFAULT_PERFORMANCE
        self.aircraft = settings_dict["aircraft"]
        self.lbAircraftName.setText(self.aircraft.name)
        self.cbShowPerformance.setChecked(settings_dict["visible"])
        self.dsbTakeoffWeight.setValue(settings_dict["takeoff_weight"])
        self.dsbEmptyWeight.setValue(
            settings_dict.get("empty_weight", settings_dict["takeoff_weight"] - settings_dict.get("fuel", 0)))
        self.dteTakeoffTime.setDateTime(settings_dict["takeoff_time"])

        # Connecting signals
        self.pbLoadPerformance.clicked.connect(self.load_performance)
        self.cbShowPerformance.stateChanged.connect(self.update_parent_performance)
        self.dteTakeoffTime.dateTimeChanged.connect(self.update_parent_performance)
        self.dsbTakeoffWeight.valueChanged.connect(self.update_parent_performance)
        self.dsbEmptyWeight.valueChanged.connect(self.update_parent_performance)

    def get_settings(self):
        """
        Encapsulates GUI selections in a python dictionary.

        :return:
         Dictionary of all setting informations
        """
        settings_dict = {
            "aircraft": self.aircraft,
            "visible": self.cbShowPerformance.isChecked(),
            "takeoff_time": self.dteTakeoffTime.dateTime(),
            "takeoff_weight": self.dsbTakeoffWeight.value(),
            "empty_weight": self.dsbEmptyWeight.value()
        }
        return settings_dict

    def update_parent_performance(self):
        self.parent.setPerformance(self.get_settings())

    def load_performance(self):
        """
        Gets a filename for a JSON file specifying aircraft performance and initializes an SimpleAircraft model.
        """
        filename = get_open_filename(
            self, "Open Aircraft Performance JSON File", constants.MSS_CONFIG_PATH,
            "Performance File (*.json)", pickertag="filepicker_default")
        if filename is not None:
            try:
                with open(filename) as tf:
                    performance = json.load(tf)
                self.aircraft = aircrafts.SimpleAircraft(performance)
                self.lbAircraftName.setText(self.aircraft.name)
                self.dsbTakeoffWeight.setValue(self.aircraft.takeoff_weight)
                if not any(hasattr(self.aircraft, _x) for _x in ("fuel", "empty_weight")):
                    raise KeyError("empty_weight")
                if hasattr(self.aircraft, "empty_weight"):
                    self.dsbEmptyWeight.setValue(self.aircraft.empty_weight)
                else:
                    self.dsbEmptyWeight.setValue(self.aircraft.takeoff_weight - self.aircraft.fuel)

                self.update_parent_performance()

            except KeyError as ex:
                QtWidgets.QMessageBox.critical(self, self.tr("Performance JSON Load"),
                                               self.tr(f"JSON File missing '{ex}' entry"))
            except (FatalUserError, ValueError) as ex:
                QtWidgets.QMessageBox.critical(self, self.tr("Performance JSON Load"),
                                               self.tr(f"JSON File has Syntax Problems:\n{ex}"))
